@@ -1,3 +1,11 @@
+P5D_HEADER = [
+    'cups',
+    'timestamp',
+    'season',
+    'ai',
+    'ae'
+]
+
 P1_HEADER = [
     'cups',
     'tipo_medida',
@@ -82,4 +90,19 @@ ALMACENACAU_HEADER = [
     'data_alta',
     'data_baixa',
     'comentari'
-]
\ No newline at end of file
+]
+
+AGRECL_HEADER = [
+    'origen',
+    'tipus_operacio',
+    'distribuidora',
+    'comercialitzadora',
+    'tensio',
+    'tarifa',
+    'dh',
+    'tipo',
+    'provincia',
+    'tipus_demanda',
+    'data_alta',
+    'data_baixa'
+]
